Re: [PATCH 1/6] control: rename variables so that it represents the number of channels which an element has

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On Feb 23 2016 09:48, Takashi Sakamoto wrote:
An element has some channels which can be changed in a single operation
from userspace. In control API, variables to represents the number of
channels is described as 'count'. On the other hand, in ALSA control core,
the number of elements in an element set is also described as 'count'.
They're a bit confusing.

This commit renames 'count' with 'channels'. The 'count' is reserved for
future commit to describe the number of elements in an element set.

Signed-off-by: Takashi Sakamoto <o-takashi@xxxxxxxxxxxxx>
---
  src/control/control.c | 38 ++++++++++++++++++++------------------
  1 file changed, 20 insertions(+), 18 deletions(-)

diff --git a/src/control/control.c b/src/control/control.c
index 8a5d530..e02727a 100644
--- a/src/control/control.c
+++ b/src/control/control.c
@@ -264,14 +264,15 @@ int snd_ctl_elem_info(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
   * \brief Create and add an user INTEGER CTL element
   * \param ctl CTL handle
   * \param id CTL element id to add
  * \param count number of elements

Oops. This is incomplete because in my intension the description of this argument represents the number of 'channels', not 'elements'.

   * \param min minimum value
   * \param max maximum value
   * \param step value step
   * \return 0 on success otherwise a negative error code
   */
  int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
-			     unsigned int count, long min, long max, long step)
+			     unsigned int channels, long min, long max,
+			     long step)
  {
  	snd_ctl_elem_info_t *info;
  	snd_ctl_elem_value_t *val;
@@ -284,7 +285,7 @@ int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  	info->type = SND_CTL_ELEM_TYPE_INTEGER;
  	info->access = SNDRV_CTL_ELEM_ACCESS_READWRITE |
  		SNDRV_CTL_ELEM_ACCESS_TLV_READWRITE;
-	info->count = count;
+	info->count = channels;
  	info->value.integer.min = min;
  	info->value.integer.max = max;
  	info->value.integer.step = step;
@@ -293,7 +294,7 @@ int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  		return err;
  	snd_ctl_elem_value_alloca(&val);
  	val->id = info->id;
-	for (i = 0; i < count; i++)
+	for (i = 0; i < channels; i++)
  		val->value.integer.value[i] = min;
  	err = ctl->ops->element_write(ctl, val);
  	return err;
@@ -303,15 +304,15 @@ int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \brief Create and add an user INTEGER64 CTL element
   * \param ctl CTL handle
   * \param id CTL element id to add
  * \param count number of elements

Ditto.

   * \param min minimum value
   * \param max maximum value
   * \param step value step
   * \return 0 on success otherwise a negative error code
   */
  int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
-			       unsigned int count, long long min, long long max,
-			       long long step)
+			       unsigned int channels, long long min,
+			       long long max, long long step)
  {
  	snd_ctl_elem_info_t *info;
  	snd_ctl_elem_value_t *val;
@@ -322,7 +323,7 @@ int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  	snd_ctl_elem_info_alloca(&info);
  	info->id = *id;
  	info->type = SND_CTL_ELEM_TYPE_INTEGER64;
-	info->count = count;
+	info->count = channels;
  	info->value.integer64.min = min;
  	info->value.integer64.max = max;
  	info->value.integer64.step = step;
@@ -331,7 +332,7 @@ int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  		return err;
  	snd_ctl_elem_value_alloca(&val);
  	val->id = info->id;
-	for (i = 0; i < count; i++)
+	for (i = 0; i < channels; i++)
  		val->value.integer64.value[i] = min;
  	err = ctl->ops->element_write(ctl, val);
  	return err;
@@ -341,11 +342,11 @@ int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \brief Create and add an user BOOLEAN CTL element
   * \param ctl CTL handle
   * \param id CTL element id to add
  * \param count number of elements

Ditto.

   * \return 0 on success otherwise a negative error code
   */
  int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
-			     unsigned int count)
+			     unsigned int channels)
  {
  	snd_ctl_elem_info_t *info;

@@ -353,7 +354,7 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  	snd_ctl_elem_info_alloca(&info);
  	info->id = *id;
  	info->type = SND_CTL_ELEM_TYPE_BOOLEAN;
-	info->count = count;
+	info->count = channels;
  	info->value.integer.min = 0;
  	info->value.integer.max = 1;
  	return ctl->ops->element_add(ctl, info);
@@ -363,7 +364,7 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \brief Create and add a user-defined control element of type enumerated.
   * \param[in] ctl Control device handle.
   * \param[in] id ID of the new control element.
  * \param[in] count Number of element values.

Ditto.

   * \param[in] items Range of possible values (0 ... \a items - 1).
   * \param[in] names An array containing \a items strings.
   * \return Zero on success, otherwise a negative error code.
@@ -380,9 +381,10 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \par Errors:
   * <dl>
   * <dt>-EBUSY<dd>A control element with ID \a id already exists.
  * <dt>-EINVAL<dd>\a count is not at least one or greater than 128, or \a items
  * 	is not at least one, or a string in \a names is empty or longer than 63
  * 	bytes, or the strings in \a names require more than 64 KB storage.
   * <dt>-ENOMEM<dd>Out of memory, or there are too many user control elements.
   * <dt>-ENXIO<dd>This driver does not support (enumerated) user controls.
   * <dt>-ENODEV<dd>Device unplugged.
@@ -392,7 +394,7 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * snd_ctl_elem_add_enumerated() was introduced in ALSA 1.0.25.
   */
  int snd_ctl_elem_add_enumerated(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
-				unsigned int count, unsigned int items,
+				unsigned int channels, unsigned int items,
  				const char *const names[])
  {
  	snd_ctl_elem_info_t *info;
@@ -405,7 +407,7 @@ int snd_ctl_elem_add_enumerated(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  	snd_ctl_elem_info_alloca(&info);
  	info->id = *id;
  	info->type = SND_CTL_ELEM_TYPE_ENUMERATED;
-	info->count = count;
+	info->count = channels;
  	info->value.enumerated.items = items;

  	bytes = 0;
@@ -264,14 +264,15 @@ int snd_ctl_elem_info(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
   * \param ctl CTL handle
   * \param id CTL element id to add
- * \param count number of elements
+ * \param channels number of elements

Oops. This is incomplete because in my intension the description of this argument represents the number of 'channels', not 'elements'.
@@ -303,15 +304,15 @@ int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \param ctl CTL handle
   * \param id CTL element id to add
- * \param count number of elements
+ * \param channels number of elements

Ditto.
@@ -341,11 +342,11 @@ int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \param ctl CTL handle
   * \param id CTL element id to add
- * \param count number of elements
+ * \param channels number of elements

Ditto.
@@ -363,7 +364,7 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * \param[in] ctl Control device handle.
   * \param[in] id ID of the new control element.
- * \param[in] count Number of element values.
+ * \param[in] channels Number of element values.

Ditto.
@@ -380,9 +381,10 @@ int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
   * <dl>
   * <dt>-EBUSY<dd>A control element with ID \a id already exists.
- * <dt>-EINVAL<dd>\a count is not at least one or greater than 128, or \a items
- * 	is not at least one, or a string in \a names is empty or longer than 63
- * 	bytes, or the strings in \a names require more than 64 KB storage.
+ * <dt>-EINVAL<dd>\a channels is not at least one or greater than 128, or \a
+ *	items is not at least one, or a string in \a names is empty or longer
+ *	than 63 bytes, or the strings in \a names require more than 64 KB
+ *	storage.
   * <dt>-ENOMEM<dd>Out of memory, or there are too many user control elements.
   * <dt>-ENXIO<dd>This driver does not support (enumerated) user controls.


Regards

Takashi Sakamoto
_______________________________________________
Alsa-devel mailing list
Alsa-devel@xxxxxxxxxxxxxxxx
http://mailman.alsa-project.org/mailman/listinfo/alsa-devel



[Index of Archives]     [ALSA User]     [Linux Audio Users]     [Kernel Archive]     [Asterisk PBX]     [Photo Sharing]     [Linux Sound]     [Video 4 Linux]     [Gimp]     [Yosemite News]

  Powered by Linux